@@ -30,6 +30,13 @@ BUTTONBOX_EDGE          = 2
 BUTTONBOX_START         = 3
 BUTTONBOX_END           = 4
 
+# GtkCalendarDisplayOptions's
+CALENDAR_SHOW_HEADING      = 1 << 0
+CALENDAR_SHOW_DAY_NAMES    = 1 << 1
+CALENDAR_NO_MONTH_CHANGE   = 1 << 2
+CALENDAR_SHOW_WEEK_NUMBERS = 1 << 3
+CALENDAR_WEEK_START_MONDAY = 1 << 4
+
 # GtkCurveType's
 CURVE_TYPE_LINEAR = 0
 CURVE_TYPE_SPLINE = 1
