@@ -374,6 +374,30 @@ class GtkWidget(GtkObject):
 		_gtk.gtk_widget_unparent(self._o)
 	def unrealize(self, obj=None):
 		_gtk.gtk_widget_unrealize(self._o)
+
+class GtkCalendar(GtkWidget):
+	get_type = _gtk.gtk_calendar_get_type
+	def __init__(self, _obj=None):
+		if _obj: self._o = _obj; return
+		self._o = _gtk.gtk_calendar_new()
+	def select_month(self, month, year):
+		return _gtk.gtk_calendar_select_month(self._o, month, year)
+	def select_day(self, day):
+		_gtk.gtk_calendar_select_day(self._o, day)
+	def mark_day(self, day):
+		return _gtk.gtk_calendar_mark_day(self._o, day)
+	def unmark_day(self, day):
+		return _gtk.gtk_calendar_unmark_day(self._o, day)
+	def clear_marks(self):
+		_gtk.gtk_calendar_clear_marks(self._o)
+	def display_options(self, flags):
+		_gtk.gtk_calendar_display_options(self._o, flags)
+	def get_date(self):
+		return _gtk.gtk_calendar_get_date(self._o)
+	def freeze(self):
+		_gtk.gtk_calendar_freeze(self._o)
+	def thaw(self):
+		_gtk.gtk_calendar_thaw(self._o)
 	
 class GtkContainer(GtkWidget):
 	get_type = _gtk.gtk_container_get_type
