@@ -46,27 +46,31 @@ class Application:
 		mainloop()
 
 	def init_menu(self):
-		self.w_menubar=GtkExtra.MenuFactory()
-		
-		self.w_menubar.add_entries([
-                        ('File/New',        None, self.process_file_new),
-                        ('File/Open...',"<control>O", self.process_file_open),
-                        ('File/Save',       None, self.process_file_save),
-                        ('File/Save As...', None, self.process_file_save_as),
-                        ('File/Close',      None, self.process_file_close),
-                        ('File/<separator>',None, None),
-                        ('File/Exit',       None, self.process_file_exit),
-
-                        ('Edit/Cut',   None, self.process_edit_cut),
-                        ('Edit/Copy',  None, self.process_edit_copy),
-                        ('Edit/Paste', None, self.process_edit_paste),
-
-                        ('Help/About', None, self.process_help_about)
-                ])
-		self.w_window.add_accel_group(self.w_menubar.accelerator)
+		ag = GtkAccelGroup()
+		itemf = GtkItemFactory(GtkMenuBar, "<main>", ag)
+		self.w_window.add_accel_group(ag)
+		file_cb = self.process_file
+		edit_cb = self.process_edit
+		help_cb = self.process_help
+		itemf.create_items([
+			('/_File',          None,         None, 0, '<Branch>'),
+			('/_File/_New',     '<control>N', file_cb, 1, ''),
+			('/_File/_Open',    '<control>O', file_cb, 2, ''),
+			('/_File/_Save',    '<control>S', file_cb, 3, ''),
+			('/_File/Save _As', None,         file_cb, 4, ''),
+			('/_File/_Close',   None,         file_cb, 5, ''),
+			('/_File/sep1',     None,   file_cb, 0, '<Separator>'),
+			('/_File/E_xit',    '<alt>F4',    file_cb, 6, ''),
+			('/_Edit',          None,         None, 0, '<Branch>'),
+			('/_Edit/C_ut',     '<control>X', edit_cb, 1, ''),
+			('/_Edit/_Copy',    '<control>C', edit_cb, 2, ''),
+			('/_Edit/_Paste',   '<control>V', edit_cb, 3, ''),
+			('/_Help',          None,         None, 0, '<LastBranch>'),
+			('/_Help/_About',   '<control>A', help_cb, 1, '')
+		])
+		self.w_menubar = itemf.get_widget('<main>')
 		self.w_vbox.pack_start(self.w_menubar, expand=FALSE)
 		self.w_menubar.show()
-		
 
 	def init_text(self):		
 		self.w_table=GtkTable(2,2,0)
@@ -94,45 +98,42 @@ class Application:
 				
 		self.w_vbox.pack_start(self.w_table)
 					
-	def process_file_new(self, mi):
-		print "process_file_new"
-		self.w_text.freeze()
-		self.w_text.set_point(0)
-		self.w_text.insert_defaults("*new file*")
-		self.w_text.thaw()
-		#self.w_text.queueDraw()
-		
-	def process_file_open(self, mi):
-		print "process_file_open"
-		print GtkExtra.file_open_box(modal=FALSE), "chosen"
+	def process_file(self, action, widget):
+		if action == 0: print "File:<unknown>"
+		elif action == 1:
+			print "File:New"
+			self.w_text.freeze()
+			self.w_text.set_point(0)
+			self.w_text.insert_defaults("*new file*")
+			self.w_text.thaw()
+			#self.w_text.queueDraw()
+		elif action == 2:
+			print "File:Open"
+			print GtkExtra.file_open_box(modal=FALSE), "chosen"
+		elif action == 3:
+			print "File:Save"
+			GtkExtra.message_box("Test Application",
+					     "Not Implemented",
+					     ("OK",), pixmap='bomb.xpm')
+		elif action == 4:
+			print "File:Save As"
+			print GtkExtra.message_box(modal=FALSE), "chosen"
+		elif action == 5:
+			print "File:Close"
+			GtkExtra.message_box("Test Application",
+					     "Not Implemented",
+					     ("OK",), pixmap='bomb.xpm')
+		elif action == 6:
+			print "File:Exit"
+			mainquit()
 
-	def process_file_save(self, mi):
-		print "process_file_save"
-		GtkExtra.message_box("Test Application", "Not Implemented",
-				     ("OK",), pixmap='bomb.xpm')
-				
-	def process_file_save_as(self, mi):
-		print "process_file_save_as"
-		print GtkExtra.message_box(modal=FALSE), "chosen"
+	def process_edit(self, action, widget):
+		if action == 0: print "Edit:<unknown>"
+		elif action == 1: print "Edit:Cut"
+		elif action == 2: print "Edit:Copy"
+		elif action == 3: print "Edit:Paste"
 
-	def process_file_close(self, mi):
-		print "process_file_close"
-		GtkExtra.message_box("Test Application", "Not Implemented",
-				     ("OK",), pixmap='bomb.xpm')
-
-	def process_file_exit(self, mi):
-		mainquit()
-		
-	def process_edit_cut(self, mi):
-		print "process_edit_cut"
-		
-	def process_edit_copy(self, mi):
-		print "process_edit_copy"
-		
-	def process_edit_paste(self, mi):
-		print "process_edit_paste"
-
-	def process_help_about(self, mi):
+	def process_help(self, action, widget):
 		GtkExtra.message_box("Test Application",
 		"""Test Application for Python-Gtk.
 		This is free software.
